@@ -188,6 +188,8 @@ def get_assume_session(
     access_key,
     session,
     role_arn,
+    policy_arns,
+    policy,
     duration_seconds=None,
     serial_number=None,
     token_code=None,
@@ -206,6 +208,15 @@ def get_assume_session(
     if token_code:
         request["TokenCode"] = token_code()
 
+    if policy_arns:
+        request["PolicyArns"] = list({"arn": v} for v in policy_arns)
+
+    if policy:
+        if policy[0] == "@":
+            with open(policy[1:]) as f:
+                policy = f.read()
+        request["Policy"] = policy
+
     if session is None:
         client = boto3.client(
             "sts",
@@ -293,7 +304,10 @@ def main(
     mfa_session_duration,
     mfa_serial_number,
     assume_role_arn,
-    force_renew,
+    assume_role_policy_arns,
+    assume_role_policy,
+    force_renew_session,
+    force_renew_assume_role,
     assume_session_duration,
 ):
     """
@@ -329,6 +343,9 @@ def main(
     if mfa_session_duration is not None:
         mfa_session_duration = int(mfa_session_duration)
 
+    if force_renew_session:
+        force_renew_assume_role = True
+
     def token_code():
         for _ in range(5):
             token_code = None
@@ -371,7 +388,7 @@ def main(
         )
 
     if assume_role_arn:
-        if force_renew:
+        if force_renew_assume_role:
             assume_session = None
         else:
             assume_session = AWSCredSession.get_cached_session(
@@ -382,7 +399,7 @@ def main(
             if mfa_session_duration == 0:
                 mfa_session = None
             else:
-                if force_renew:
+                if force_renew_session:
                     mfa_session = get_mfa_session(*mfa_session_request)
                 else:
                     mfa_session = get_mfa_session_cached(*mfa_session_request)
@@ -396,13 +413,20 @@ def main(
                     access_key,
                     mfa_session,
                     assume_role_arn,
+                    assume_role_policy_arns,
+                    assume_role_policy,
                     assume_session_duration,
                     mfa_serial_number,
                     token_code,
                 )
             else:
                 assume_session = get_assume_session(
-                    access_key, mfa_session, assume_role_arn, assume_session_duration
+                    access_key,
+                    mfa_session,
+                    assume_role_arn,
+                    assume_role_policy_arns,
+                    assume_role_policy,
+                    assume_session_duration,
                 )
 
         if assume_session is None:
@@ -415,7 +439,7 @@ def main(
             logging.warning("Cannot do MFA without session")
             sys.exit(1)
 
-        if force_renew:
+        if force_renew_session:
             mfa_session = get_mfa_session(*mfa_session_request)
         else:
             mfa_session = get_mfa_session_cached(*mfa_session_request)
@@ -441,7 +465,17 @@ def main(
 )
 @click.option("--assume-session-duration", help="duration in seconds", type=int)
 @click.option("--assume-role-arn", help="IAM Role to be assumed, optional")
-@click.option("--force-renew", is_flag=True)
+@click.option(
+    "--assume-role-policy-arns",
+    help="Assume role with policy ARN, can be used multiple times",
+    multiple=True,
+)
+@click.option(
+    "--assume-role-policy",
+    help="Assume role with this policy, you can use a filename if this value starts with @",
+)
+@click.option("--force-renew-session", is_flag=True)
+@click.option("--force-renew-assume-role", is_flag=True)
 @click.option("--credentials-section", help="Use this section from ~/.aws/credentials")
 @click.option(
     "--pin-entry",
@@ -458,7 +492,10 @@ def click_main(
     secret_access_key,
     assume_session_duration,
     assume_role_arn,
-    force_renew,
+    assume_role_policy_arns,
+    assume_role_policy,
+    force_renew_session,
+    force_renew_assume_role,
     credentials_section,
     pin_entry,
     log_file,
@@ -501,12 +538,18 @@ def click_main(
         config["assume_session_duration"] = assume_session_duration
     if assume_role_arn:
         config["assume_role_arn"] = assume_role_arn
-    if force_renew:
-        config["force_renew"] = force_renew
+    if force_renew_session:
+        config["force_renew_session"] = force_renew_session
+    if force_renew_assume_role:
+        config["force_renew_assume_role"] = force_renew_assume_role
     if credentials_section:
         config["credentials_section"] = credentials_section
     if pin_entry:
         config["pin_entry"] = pin_entry
+    if assume_role_policy_arns:
+        config["assume_role_policy_arns"] = assume_role_policy_arns
+    if assume_role_policy:
+        config["assume_role_policy"] = assume_role_policy
 
     if not config.get("mfa_serial_number"):
         click.echo("Required mfa_serial_number not set", err=True)
@@ -522,6 +565,9 @@ def click_main(
         config.get("mfa_session_duration"),
         config.get("mfa_serial_number"),
         config.get("assume_role_arn"),
-        config.get("force_renew", False),
+        config.get("assume_role_policy_arns"),
+        config.get("assume_role_policy"),
+        config.get("force_renew_session", False),
+        config.get("force_renew_assume_role", False),
         config.get("assume_session_duration"),
     )
